@@ -1,10 +1,10 @@
 #[macro_export]
 macro_rules! rust_2018 {
     ($($t:tt)*) => {
-        $crate::__export::reedition!(
+        $crate::__export::reedition! {
             hello
             ($($t)*)
-        )
+        }
     }
 }
 
